document.addEventListener('DOMContentLoaded', function() {
  // Mobile menu toggle
  const menuToggle = document.querySelector('.menu-toggle');
  const navLinks = document.querySelector('.nav-links');
  
  menuToggle.addEventListener('click', function() {
    navLinks.style.display = navLinks.style.display === 'flex' ? 'none' : 'flex';
    this.classList.toggle('active');
  });

  // Smooth scroll for navigation links
  document.querySelectorAll('a[href^="#"]').forEach(anchor => {
    anchor.addEventListener('click', function(e) {
      e.preventDefault();
      const target = document.querySelector(this.getAttribute('href'));
      
      if (target) {
        window.scrollTo({
          top: target.offsetTop - 80,
          behavior: 'smooth'
        });
      }
      
      // Close mobile menu if open
      if (window.innerWidth <= 768) {
        navLinks.style.display = 'none';
        menuToggle.classList.remove('active');
      }
    });
  });

  // Form submission handling
  const applicationForm = document.getElementById('applicationForm');
  
  applicationForm.addEventListener('submit', function(e) {
    e.preventDefault();
    
    // Form validation
    const requiredFields = applicationForm.querySelectorAll('[required]');
    let isValid = true;
    
    requiredFields.forEach(field => {
      if (!field.value.trim()) {
        isValid = false;
        field.style.borderColor = '#ff0000';
      } else {
        field.style.borderColor = '#eee';
      }
    });
    
    if (isValid) {
      // Show success message
      const submitButton = applicationForm.querySelector('.submit-button');
      const originalText = submitButton.textContent;
      
      submitButton.textContent = 'Application Submitted!';
      submitButton.style.backgroundColor = '#4CAF50';
      
      // Reset form and button after delay
      setTimeout(() => {
        applicationForm.reset();
        submitButton.textContent = originalText;
        submitButton.style.backgroundColor = '';
      }, 3000);
    }
  });

  // Intersection Observer for animations
  const observerOptions = {
    threshold: 0.1,
    rootMargin: '0px 0px -50px 0px'
  };

  const observer = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        entry.target.style.opacity = '1';
        entry.target.style.transform = 'translateY(0)';
      }
    });
  }, observerOptions);

  // Observe sections for fade-in effect
  document.querySelectorAll('section').forEach(section => {
    section.style.opacity = '0';
    section.style.transform = 'translateY(20px)';
    section.style.transition = 'all 0.6s ease-out';
    observer.observe(section);
  });
});